==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/common/poznamkykednibrowser.php <==
<?php
/**
 * stanislav.elbl, 25.01.2021
 */

namespace RonPortal\Common;

use Ron\Controls\BrowserField;
use Ron\Controls\LinksList;
use Ron\DB\Database;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;
use RonPortal\RonPortalSession;
use RonPortal\RozdeleniUtils;


class PoznamkyKeDniFilterForm extends RonPortalFilterForm
{
    /** @var int    0 = aktualni, 1 = vse */
    public $poznamkyKeDniFiltr;

    private function renderFilterStav()
    {
        $filterarray = [
            0 => TextManager::_('Poznamky_ke_dni_aktualni'),
            1 => TextManager::_('Poznamky_ke_dni_vse')
        ];

        echo '<div class="filterrow" id="filtr_poznamkyaktualni">';
        echo '<span class="filtercaption"></span>';
        LinksList::renderLinks($filterarray,
            RonPortalSession::getValue('poznamkykedni_filtr'),
            '?menuid=poznamkykedni&poznamky_filtr=', '', false);
        echo "</div>\n";
    }


    public function loadData()
    {
        parent::loadData();

        if (isset($_GET['poznamky_filtr'])) {
            $this ->poznamkyKeDniFiltr = (int)$_GET['poznamky_filtr'];
            $_SESSION['poznamkykedni_filtr'] = $this ->poznamkyKeDniFiltr;
        } else {
            $this ->poznamkyKeDniFiltr = RonPortalSession::getValue('poznamkykedni_filtr');
        }
    }


    public function renderFilters()
    {
        parent::renderFilters();

        // aktualni a budouci / vsechny
        $this->renderFilterStav();
    }
}


class PoznamkaKeDniDetailField extends BrowserField
{

    /**
     * PoznamkaKeDniDetailField constructor.
     */
    public function __construct()
    {
        parent::__construct();
        $this ->type = BrowserField::FIELD_TYPE_TEXT;
        $this ->link = '#';
    }

    public function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        return
            "<span class='open-dialog' data-dialog='#poznamky_ke_dni_dialog'" .
            //" data-ronform-url='?menuid=poznamkykedni&action=loaddata&record={$rowData[0]}'>" .
            " data-ronform-record='{$rowData[0]}'>" .
            parent::getViewText($value, $rowNumber, $recordId, $rowData) .
            '</span>';
    }


}



class PoznamkyKeDniBrowser extends RonPortalBrowser
{

    /**
     * PoznamkyKeDniBrowser constructor.
     * @param Database $database
     * @param string $action
     */
    public function __construct($database, $action)
    {
        parent::__construct($database, $action);

        $this ->title = TextManager::_('Poznamky_ke_dni');
        $this ->code = 'browserpoznamkykedni';

        $this ->sqlFromPart =
            'PoznamkaKeDni INNER JOIN TypPoznamkyKeDni' .
            '  ON PoznamkaKeDni.Typ = TypPoznamkyKeDni.Kod' .
            ' LEFT OUTER JOIN Rozdeleni' .
            '  ON Rozdeleni.KodTypuRozdeleni = PoznamkaKeDni.KodTypuRozdeleni' .
            '  AND Rozdeleni.Kod = PoznamkaKeDni.Rozdeleni';

        $this ->sqlSelectPart =
            'PoznamkaKeDni.Id, PoznamkaKeDni.DatumOd, PoznamkaKeDni.DatumDo, PoznamkaKeDni.Popis,' . // 0..3
            ' PoznamkaKeDni.Typ, TypPoznamkyKeDni.Popis,' .
            ' PoznamkaKeDni.KodTypuRozdeleni, PoznamkaKeDni.Rozdeleni, Rozdeleni.Popis, ' .     // 6..8
            $database ->castWideMemo('PoznamkaKeDni.Poznamka');

        $this ->addField()
            ->setSqlFieldName('PoznamkaKeDni.DatumOd', 1) ->setFormat('date') ->setHeaderText('Datum_od')
            ->setCode('col-datum-od')
            ->setOrdering(true);

        $this ->defaultSort = -count($this ->fields);

        $this ->addField()
            ->setSqlFieldName('PoznamkaKeDni.DatumDo', 2) ->setFormat('date') ->setHeaderText('Datum_do')
            ->setCode('col-datum-do')
            ->setOrdering(true);

        $this ->addField()
            ->setSqlFieldName('TypPoznamkyKeDni.Popis', 5) ->setHeaderText('Typ')
            ->setCode('col-typ')
            ->setOrdering(true);

        $this ->addField()
            ->setSqlFieldName('PoznamkaKeDni.Popis', 3) ->setHeaderText('Popis')
            ->setCode('col-popis')
            ->setOrdering(true);

        $this ->addField()
            ->setSqlFieldName('Rozdeleni.Popis', 8) ->setHeaderText('Rozdeleni')
            ->setCode('col-rozdeleni')
            ->setOrdering(true);

        $this ->addField()
            ->setSqlFieldName('PoznamkaKeDni.Rozdeleni', 7) ->setHeaderText('Kod')
            ->setCode('col-kod-rozdeleni')
            ->setOrdering(true);

        $this ->addField(new PoznamkaKeDniDetailField())
            ->setCode('col-detail') ->setText('Detail')
            ->setClassName('dialogopen');
    }


    public function setFilterForm()
    {
        $this ->filterForm = new PoznamkyKeDniFilterForm($this ->database, 'poznamkykedni', true);

        $this ->filterForm ->nastavRozdeleni(true);
        $this ->filterForm ->f_pravarozdeleni = Prava::vratPrava('poznamkykedni');

        $this ->filterForm ->showDatumOdDo = true;
    }


    public function getSQLFilter()
    {
        $params = $this ->database ->createParameters();
        $result = '';

        /** @noinspection PhpPossiblePolymorphicInvocationInspection */
        switch ($this ->filterForm ->poznamkyKeDniFiltr) {
            case 1 :    // vse
                break;

            case 0 :
            default :
                $result = 'DatumDo >= '  . $params ->addParameter($this ->database ->dateToParam(time()));
                break;
        }

        if ($this ->filterForm ->filtrovatDatum) {
            $result = ($result ? ' AND ' : '') .
                'DatumOd <= ' . $params ->addParameter($this ->database ->dateToParam($this ->filterForm ->datumDo)) .
                ' AND DatumDo >= ' . $params ->addParameter($this ->database ->dateToParam($this ->filterForm ->datumOd));
        }

        if (isset($this ->filterForm ->kodRozdeleni)) {
            $filterRozdeleni = RozdeleniUtils::sqlFilterRozdeleni($this ->database, 'PoznamkaKeDni',
                $this ->filterForm ->f_typrozdeleni, $this ->filterForm ->kodRozdeleni, $this ->filterForm ->vcetnePodrizenychRozdeleni, $params);

            if ($filterRozdeleni) {
                $result .= ($result ? ' AND ' : '') . $filterRozdeleni;
            }
        }

        $prava = Prava::vratPrava('poznamkykedni');
        $filtrPrava = $prava ->sqlfiltrRozdeleni(
            $this ->filterForm ->filtrovatDatum ? $this ->filterForm ->datumOd : null,
            $this ->filterForm ->filtrovatDatum ? $this ->filterForm ->datumDo : null,
            1); // v pripade, ze nejde filtrovat podle prav, tak nezobrazi nic

        if ($filtrPrava) {
            $result .= ($result ? ' AND ' : '') . ' (' . $filtrPrava . ')';
        }

        return $result
            ? new SqlStatement($result, $params)
            : '';
    }


    function renderFilter()
    {
        parent::renderFilter();
        echo
            '<div class="margin-top-2">' .
            '<span class="open-dialog" data-dialog="#poznamky_ke_dni_dialog">' .
            '<a href="#">' . TextManager::_('Vlozit_novou_poznamku') . '</a>' .
            '</span>' .
            '</div>';
    }


    public function render()
    {
        parent::render();

        // zobrazi dialog pro vkladani a editaci
        $form = new PoznamkyKeDniFormular($this ->database);
        $form ->render();
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/common/poznamkykednibrowser.php <==
<?php
/**
 * stanislav.elbl, 25.01.2021
 * Seznam poznamek ke dni (z tabulky PoznamkaKeDni)
 */

namespace RonPortal\Common;

use Ron\Controls\BrowserField;
use Ron\Controls\LinksList;
use Ron\DB\Database;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;
use RonPortal\RonPortalSession;
use RonPortal\RozdeleniUtils;


class PoznamkyKeDniFilterForm extends RonPortalFilterForm
{
    /** @var int    0 = aktualni, 1 = vse */
    public $poznamkyKeDniFiltr;

    private function renderFilterStav()
    {
        $filterarray = [
            0 => TextManager::_('Poznamky_ke_dni_aktualni'),
            1 => TextManager::_('Poznamky_ke_dni_vse')
        ];

        echo '<div class="filterrow" id="filtr_poznamkyaktualni">';
        echo '<span class="filtercaption"></span>';
        LinksList::renderLinks($filterarray,
            $this ->poznamkyKeDniFiltr,
            '?menuid=poznamkykedni&poznamky_filtr=', '', false);
        echo "</div>\n";
    }


    public function loadData()
    {
        parent::loadData();

        if (isset($_GET['poznamky_filtr'])) {
            $this ->poznamkyKeDniFiltr = (int)$_GET['poznamky_filtr'];
            $_SESSION['poznamkykedni_filtr'] = $this ->poznamkyKeDniFiltr;
        } else {
            $this ->poznamkyKeDniFiltr = RonPortalSession::getValue('poznamkykedni_filtr');
        }
    }


    public function renderFilters()
    {
        parent::renderFilters();

        // aktualni a budouci / vsechny
        $this->renderFilterStav();
    }
}


/**
 * Class PoznamkaKeDniDetailField
 * Proklik na dialog
 */
class PoznamkaKeDniDetailField extends BrowserField
{

    /**
     * PoznamkaKeDniDetailField constructor.
     */
    public function __construct()
    {
        parent::__construct();
        $this ->setType(BrowserField::FIELD_TYPE_TEXT);
        //$this ->link = '#';
    }

    public function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        return
            "<span class='open-dialog js' data-dialog='#poznamky_ke_dni_dialog'" .
            //" data-ronform-url='?menuid=poznamkykedni&action=loaddata&record={$rowData[0]}'>" .
            " data-ronform-record='{$rowData['col-id']}'>" .
            parent::getViewText($value, $rowNumber, $recordId, $rowData) .
            '</span>';
    }
}


/**
 * Class PoznamkyKeDniBrowser
 * Seznam poznamek ke dni (z tabulky PoznamkaKeDni)
 */
class PoznamkyKeDniBrowser extends RonPortalBrowser
{

    /**
     * PoznamkyKeDniBrowser constructor.
     * @param Database $database
     * @param string $action
     */
    public function __construct($database, $action)
    {
        parent::__construct($database, $action);

        $this ->title = TextManager::_('Poznamky_ke_dni');
        $this ->code = 'browserpoznamkykedni';

        $this ->sqlFromPart =
            'PoznamkaKeDni INNER JOIN TypPoznamkyKeDni' .
            '  ON PoznamkaKeDni.Typ = TypPoznamkyKeDni.Kod' .
            ' LEFT OUTER JOIN Rozdeleni' .
            '  ON Rozdeleni.KodTypuRozdeleni = PoznamkaKeDni.KodTypuRozdeleni' .
            '  AND Rozdeleni.Kod = PoznamkaKeDni.Rozdeleni';

        $this ->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('PoznamkaKeDni.Id')
            ->setCode('col-id');

        $this ->addField()
            ->setSqlFieldName('PoznamkaKeDni.DatumOd') ->setFormat('date') ->setHeaderText('Datum_od')
            ->setCode('col-datum-od')
            ->setOrdering(true);

        $this ->defaultSort = '-col-datum-od';

        $this ->addField()
            ->setSqlFieldName('PoznamkaKeDni.DatumDo') ->setFormat('date') ->setHeaderText('Datum_do')
            ->setCode('col-datum-do')
            ->setOrdering(true);

        $this ->addField()
            ->setSqlFieldName('TypPoznamkyKeDni.Popis') ->setHeaderText('Typ')
            ->setCode('col-typ')
            ->setOrdering(true);

        $this ->addField()
            ->setSqlFieldName('PoznamkaKeDni.Popis') ->setHeaderText('Popis')
            ->setCode('col-popis')
            ->setOrdering(true);

        $this ->addField()
            ->setSqlFieldName('Rozdeleni.Popis') ->setHeaderText('Rozdeleni')
            ->setCode('col-rozdeleni')
            ->setOrdering(true);

        $this ->addField()
            ->setSqlFieldName('PoznamkaKeDni.Rozdeleni') ->setHeaderText('Kod')
            ->setCode('col-kod-rozdeleni')
            ->setOrdering(true);

        $this ->addField(new PoznamkaKeDniDetailField())
            ->setCode('col-detail') ->setText('Detail')
            ->setClassName('dialogopen');
    }


    public function setFilterForm()
    {
        $this ->filterForm = new PoznamkyKeDniFilterForm($this ->database, 'poznamkykedni', true);

        $this ->filterForm ->nastavRozdeleni(true);
        $this ->filterForm ->f_pravarozdeleni = Prava::vratPrava('poznamkykedni');

        $this ->filterForm ->showDatumOdDo = true;
    }


    public function getSQLFilter()
    {
        $params = $this ->database ->createParameters();
        $result = '';

        if ($this ->filterForm instanceof PoznamkyKeDniFilterForm) {
            switch ($this->filterForm->poznamkyKeDniFiltr) {
                case 1 :    // vse
                    break;

                case 0 :
                default :
                    $result = 'DatumDo >= ' . $params->addParameter($this->database->dateToParam(time()));
                    break;
            }
        }

        if ($this ->filterForm ->filtrovatDatum) {
            $result = ($result ? ' AND ' : '') .
                'DatumOd <= ' . $params ->addParameter($this ->database ->dateToParam($this ->filterForm ->datumDo)) .
                ' AND DatumDo >= ' . $params ->addParameter($this ->database ->dateToParam($this ->filterForm ->datumOd));
        }

        if (isset($this ->filterForm ->kodRozdeleni)) {
            $filterRozdeleni = RozdeleniUtils::sqlFilterRozdeleni($this ->database, 'PoznamkaKeDni',
                $this ->filterForm ->kodTypuRozdeleni, $this ->filterForm ->kodRozdeleni, $this ->filterForm ->vcetnePodrizenychRozdeleni, $params);

            if ($filterRozdeleni) {
                $result .= ($result ? ' AND ' : '') . $filterRozdeleni;
            }
        }

        $prava = Prava::vratPrava('poznamkykedni');
        $filtrPrava = $prava ->sqlfiltrRozdeleni(
            $this ->filterForm ->filtrovatDatum ? $this ->filterForm ->datumOd : null,
            $this ->filterForm ->filtrovatDatum ? $this ->filterForm ->datumDo : null,
            1); // v pripade, ze nejde filtrovat podle prav, tak nezobrazi nic

        if ($filtrPrava) {
            $result .= ($result ? ' AND ' : '') . ' (' . $filtrPrava . ')';
        }

        return $result
            ? new SqlStatement($result, $params)
            : '';
    }


    function renderFilter()
    {
        parent::renderFilter();
        echo
            '<div class="margin-top-2">' .
            '<span class="open-dialog" data-dialog="#poznamky_ke_dni_dialog">' .
            '<a href="#">' . TextManager::_('Vlozit_novou_poznamku') . '</a>' .
            '</span>' .
            '</div>';
    }


    public function render()
    {
        parent::render();

        // zobrazi dialog pro vkladani a editaci
        $form = new PoznamkyKeDniFormular($this ->database);
        $form ->render();
    }
}
